summaryrefslogtreecommitdiffstats
path: root/khtml/xml/dom2_eventsimpl.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
commitf7e71d47719ab6094cf4a9fafffa5ea351973522 (patch)
tree30834aa632d442019e14f88685001d94657d060b /khtml/xml/dom2_eventsimpl.cpp
parentb31cfd9a1ee986fe2ae9a693f3afd7f171dd897c (diff)
downloadtdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.tar.gz
tdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.zip
Initial conversion for TQt for Qt4 3.4.0 TP2
This will also compile with TQt for Qt3, and should not cause any problems with dependent modules such as kdebase. If it does then it needs to be fixed! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1214149 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/xml/dom2_eventsimpl.cpp')
-rw-r--r--khtml/xml/dom2_eventsimpl.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/khtml/xml/dom2_eventsimpl.cpp b/khtml/xml/dom2_eventsimpl.cpp
index bcc2fca3a..c648ed63e 100644
--- a/khtml/xml/dom2_eventsimpl.cpp
+++ b/khtml/xml/dom2_eventsimpl.cpp
@@ -48,7 +48,7 @@ EventImpl::EventImpl()
m_currentTarget = 0;
m_eventPhase = 0;
m_target = 0;
- m_createTime = TQDateTime::currentDateTime();
+ m_createTime = TQDateTime::tqcurrentDateTime();
m_defaultHandled = false;
}
@@ -67,7 +67,7 @@ EventImpl::EventImpl(EventId _id, bool canBubbleArg, bool cancelableArg)
m_currentTarget = 0;
m_eventPhase = 0;
m_target = 0;
- m_createTime = TQDateTime::currentDateTime();
+ m_createTime = TQDateTime::tqcurrentDateTime();
m_defaultHandled = false;
}
@@ -499,14 +499,14 @@ public:
}
L toLeft(R r) {
- TQMapIterator<R,L> i( m_rToL.find(r) );
+ TQMapIterator<R,L> i( m_rToL.tqfind(r) );
if (i != m_rToL.end())
return *i;
return L();
}
R toRight(L l) {
- TQMapIterator<L,R> i = m_lToR.find(l);
+ TQMapIterator<L,R> i = m_lToR.tqfind(l);
if (i != m_lToR.end())
return *i;
return R();
@@ -590,10 +590,10 @@ KeyEventBaseImpl::KeyEventBaseImpl(EventId id, bool canBubbleArg, bool cancelabl
m_keyVal = key->ascii();
m_virtKeyVal = virtKeyToQtKey()->toLeft(key->key());
// m_keyVal should contain the unicode value
// of the pressed key if available.
if (m_virtKeyVal == DOM_VK_UNDEFINED && !key->text().isEmpty())
- m_keyVal = key->text().unicode()[0];
+ m_keyVal = key->text().tqunicode()[0];
// key->state returns enum ButtonState, which is ShiftButton, ControlButton and AltButton or'ed together.
m_modifier = key->state();
@@ -739,10 +739,10 @@ DOMString KeyboardEventImpl::keyIdentifier() const
{
if (unsigned special = virtKeyVal())
if (const char* id = keyIdentifiersToVirtKeys()->toLeft(special))
- return TQString::fromLatin1(id);
+ return TQString::tqfromLatin1(id);
- if (unsigned unicode = keyVal())
- return TQString(TQChar(unicode));
+ if (unsigned tqunicode = keyVal())
+ return TQString(TQChar(tqunicode));
return "Unidentified";
}
@@ -773,9 +773,9 @@ void KeyboardEventImpl::initKeyboardEvent(const DOMString &typeArg,
//Figure out the code information from the key identifier.
if (keyIdentifierArg.length() == 1) {
//Likely to be normal unicode id, unless it's one of the few
//special values.
- unsigned short code = keyIdentifierArg.unicode()[0];
+ unsigned short code = keyIdentifierArg.tqunicode()[0];
if (code > 0x20 && code != 0x7F)
keyVal = code;
}
@@ -819,7 +819,7 @@ int KeyboardEventImpl::keyCode() const
if (m_virtKeyVal != DOM_VK_UNDEFINED)
return m_virtKeyVal;
else
- return TQChar((unsigned short)m_keyVal).upper().unicode();
+ return TQChar((unsigned short)m_keyVal).upper().tqunicode();
}
int KeyboardEventImpl::charCode() const
@@ -856,14 +856,14 @@ void TextEventImpl::initTextEvent(const DOMString &typeArg,
//See whether we can get a key out of this.
unsigned keyCode = 0;
if (text.length() == 1)
- keyCode = text.unicode()[0].unicode();
+ keyCode = text.tqunicode()[0].tqunicode();
initKeyBaseEvent(typeArg, canBubbleArg, cancelableArg, viewArg,
keyCode, 0, 0);
}
int TextEventImpl::keyCode() const
{
//Mozilla returns 0 here unless this is a non-unicode key.
//IE stuffs everything here, and so we try to match it..
if (m_keyVal)
return m_keyVal;
@@ -872,8 +872,8 @@ int TextEventImpl::keyCode() const
int TextEventImpl::charCode() const
{
//On text events, in Mozilla charCode is 0 for non-unicode keys,
//and the unicode key otherwise... IE doesn't support this.
if (m_virtKeyVal)
return 0;
return m_keyVal;
@@ -590,10 +590,10 @@ KeyEventBaseImpl::KeyEventBaseImpl(EventId id, bool canBubbleArg, bool cancelabl
m_keyVal = key->ascii();
m_virtKeyVal = virtKeyToQtKey()->toLeft(key->key());
- // m_keyVal should contain the unicode value
+ // m_keyVal should contain the tqunicode value
// of the pressed key if available.
if (m_virtKeyVal == DOM_VK_UNDEFINED && !key->text().isEmpty())
@@ -773,9 +773,9 @@ void KeyboardEventImpl::initKeyboardEvent(const DOMString &typeArg,
//Figure out the code information from the key identifier.
if (keyIdentifierArg.length() == 1) {
- //Likely to be normal unicode id, unless it's one of the few
+ //Likely to be normal tqunicode id, unless it's one of the few
//special values.
@@ -856,14 +856,14 @@ void TextEventImpl::initTextEvent(const DOMString &typeArg,
int TextEventImpl::keyCode() const
{
- //Mozilla returns 0 here unless this is a non-unicode key.
+ //Mozilla returns 0 here unless this is a non-tqunicode key.
//IE stuffs everything here, and so we try to match it..
if (m_keyVal)
@@ -872,8 +872,8 @@ int TextEventImpl::keyCode() const
int TextEventImpl::charCode() const
{
- //On text events, in Mozilla charCode is 0 for non-unicode keys,
- //and the unicode key otherwise... IE doesn't support this.
+ //On text events, in Mozilla charCode is 0 for non-tqunicode keys,
+ //and the tqunicode key otherwise... IE doesn't support this.
if (m_virtKeyVal)
return 0;